@@ -25,75 +25,92 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qslider.h>
-#include <qpainter.h>
-#include <kapplication.h>
-#include <ksimpleconfig.h>
 #include "amordialog.h"
 #include "amordialog.moc"
-#include "version.h"
-#include <klocale.h>
-#include <qvbox.h>
-#include <kstandarddirs.h>
+
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QListWidget>
+#include <QtGui/QSlider>
+#include <KTextEdit>
+#include <QtGui/QPixmap>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QVBoxLayout>
+#include <KConfig>
+#include <KIcon>
+#include <KLocale>
+#include <KStandardDirs>
+#include <KGlobal>
 
 //---------------------------------------------------------------------------
 //
 // Constructor
 //
 AmorDialog::AmorDialog()
-    : KDialogBase(0, "amordlg", false, i18n("Options"), Ok|Apply|Cancel, Ok )
+    : KDialog(0)
 {
-    mConfig.read();
-    QVBox *mainwidget = makeVBoxMainWidget();
+    setCaption( i18n("Options") );
+    setButtons( Ok|Apply|Cancel );
+    setDefaultButton( Ok );
 
-    QHBox *hb = new QHBox(mainwidget);
+    mConfig.read();
+    QWidget *mainwidget = new QWidget(this);
+    setMainWidget( mainwidget );
+    QGridLayout *gridLayout = new QGridLayout(mainwidget);
+    gridLayout->setMargin(0);
 
     // Theme list
-    QVBox *themeBox = new QVBox(hb);
-    themeBox->setSpacing(spacingHint());
+    QLabel *label = new QLabel(i18n("Theme:"), mainwidget);
+    gridLayout->addWidget(label, 0, 0);
 
-    QLabel *label = new QLabel(i18n("Theme:"), themeBox);
-
-    mThemeListBox = new QListBox(themeBox);
-    connect(mThemeListBox,SIGNAL(highlighted(int)),SLOT(slotHighlighted(int)));
-    mThemeListBox->setMinimumSize( fontMetrics().maxWidth()*20,
+    mThemeListView = new QListWidget(mainwidget);
+    mThemeListView->setIconSize(QSize(32, 32));
+    mThemeListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    mThemeListView->setAlternatingRowColors(true);
+    connect(mThemeListView,SIGNAL(currentRowChanged(int)),SLOT(slotHighlighted(int)));
+    mThemeListView->setMinimumSize( fontMetrics().maxWidth()*20,
 				   fontMetrics().lineSpacing()*6 );
+    gridLayout->addWidget(mThemeListView, 1, 0);
 
-    mAboutEdit = new QMultiLineEdit(themeBox);
+    mAboutEdit = new KTextEdit(mainwidget);
     mAboutEdit->setReadOnly(true);
     mAboutEdit->setMinimumHeight( fontMetrics().lineSpacing()*4 );
-
-    themeBox->setStretchFactor(mThemeListBox, 4);
-    themeBox->setStretchFactor(mAboutEdit, 1);
+    gridLayout->addWidget(mAboutEdit, 2, 0);
 
     // Animation offset
-    QVBox *offsetBox = new QVBox(hb);
-    offsetBox->setSpacing(spacingHint());
-    label = new QLabel(i18n("Offset:"), offsetBox);
+    label = new QLabel(i18n("Offset:"), mainwidget);
+    gridLayout->addWidget(label, 0, 1);
 
-    QSlider *slider = new QSlider(-40, 40, 5, mConfig.mOffset,
-                                    QSlider::Vertical, offsetBox);
+    QSlider *slider = new QSlider(Qt::Vertical, mainwidget);
+    slider->setRange(-40, 40);
+    slider->setPageStep(5);
+    slider->setValue(mConfig.mOffset);
     connect(slider, SIGNAL(valueChanged(int)), SLOT(slotOffset(int)));
+    gridLayout->addWidget(slider, 1, 1, 2, 1);
 
     // Always on top
     QCheckBox *checkBox = new QCheckBox(i18n("Always on top"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotOnTop(bool)));
     checkBox->setChecked(mConfig.mOnTop);
+    gridLayout->addWidget(checkBox, 3, 0, 1, 2);
 
     checkBox = new QCheckBox(i18n("Show random tips"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotRandomTips(bool)));
     checkBox->setChecked(mConfig.mTips); // always keep this one after the connect, or the QList would not be grayed when it should
+    gridLayout->addWidget(checkBox, 4, 0, 1, 2);
 
     checkBox = new QCheckBox(i18n("Use a random character"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotRandomTheme(bool)));
     checkBox->setChecked(mConfig.mRandomTheme);
+    gridLayout->addWidget(checkBox, 5, 0, 1, 2);
 
     checkBox = new QCheckBox(i18n("Allow application tips"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotApplicationTips(bool)));
     checkBox->setChecked(mConfig.mAppTips);
-
+    gridLayout->addWidget(checkBox, 6, 0, 1, 2);
+    connect(this,SIGNAL(okClicked()),SLOT(slotOk()));
+    connect(this,SIGNAL(applyClicked()),SLOT(slotApply()));
+    connect(this,SIGNAL(cancelClicked()),SLOT(slotCancel()));
     readThemes();
 }
 
@@ -115,7 +132,7 @@ void AmorDialog::readThemes()
 
     // Non-recursive search for theme files, with the relative paths stored
     // in files so that absolute paths are not used.
-    KGlobal::dirs()->findAllResources("appdata", "*rc", false, false, files);
+    KGlobal::dirs()->findAllResources("appdata", "*rc", KStandardDirs::NoSearchOptions, files);
 
     for (QStringList::ConstIterator it = files.begin();
 	 it != files.end();
@@ -129,40 +146,39 @@ void AmorDialog::readThemes()
 //
 void AmorDialog::addTheme(const QString& file)
 {
-    KSimpleConfig config(locate("appdata", file), true);
+    KConfig config(KStandardDirs::locate("appdata", file));
 
-    config.setGroup("Config");
+    KConfigGroup configGroup( &config, "Config" );
 
-    QString pixmapPath = config.readPathEntry("PixmapPath");
+    QString pixmapPath = configGroup.readPathEntry("PixmapPath", QString());
     if (pixmapPath.isEmpty())
     {
         return;
     }
 
-    pixmapPath += "/";
+    pixmapPath += '/';
 
     if (pixmapPath[0] != '/')
     {
         // relative to config file. We add a / to indicate the dir
-        pixmapPath = locate("appdata", pixmapPath);
+        pixmapPath = KStandardDirs::locate("appdata", pixmapPath);
     }
 
-    QString description = config.readEntry("Description");
-    QString about = config.readEntry("About", " ");
-    QString pixmapName = config.readEntry("Icon");
+    QString description = configGroup.readEntry("Description");
+    QString about = configGroup.readEntry("About", " ");
+    QString pixmapName = configGroup.readEntry("Icon");
 
     pixmapPath += pixmapName;
 
     QPixmap pixmap(pixmapPath);
 
-    AmorListBoxItem *item = new AmorListBoxItem(description, pixmap);
-    mThemeListBox->insertItem(item);
+    QListWidgetItem *item = new QListWidgetItem(KIcon(pixmap), description, mThemeListView);
     mThemes.append(file);
     mThemeAbout.append(about);
 
     if (mConfig.mTheme == file)
     {
-        mThemeListBox->setSelected(mThemeListBox->count()-1, true);
+        mThemeListView->setCurrentItem(item);
     }
 }
 
@@ -172,8 +188,10 @@ void AmorDialog::addTheme(const QString& file)
 //
 void AmorDialog::slotHighlighted(int index)
 {
-    mConfig.mTheme = *mThemes.at(index);
-    mAboutEdit->setText(*mThemeAbout.at(index));
+    if (index < 0)
+        return;
+    mConfig.mTheme = mThemes.at(index);
+    mAboutEdit->setPlainText(mThemeAbout.at(index));
 }
 
 //---------------------------------------------------------------------------
@@ -210,7 +228,7 @@ void AmorDialog::slotRandomTips(bool tips)
 //
 void AmorDialog::slotRandomTheme(bool randomTheme)
 {
-    mThemeListBox->setEnabled(!randomTheme);
+    mThemeListView->setEnabled(!randomTheme);
     mConfig.mRandomTheme = randomTheme;
 }
 
@@ -251,35 +269,8 @@ void AmorDialog::slotApply()
 void AmorDialog::slotCancel()
 {
     // restore offset
-    KConfig *config = kapp->config();
-    KConfigGroupSaver cs(config, "General");
-    emit offsetChanged(config->readNumEntry("Offset"));
+    KSharedConfig::Ptr config = KGlobal::config();
+    KConfigGroup cs(config, "General");
+    emit offsetChanged(cs.readEntry("Offset",0));
     reject();
 }
-
-//===========================================================================
-//
-// AmorListBoxItem implements a list box items for selection of themes
-//
-void AmorListBoxItem::paint( QPainter *p )
-{
-    p->drawPixmap( 3, 0, mPixmap );
-    QFontMetrics fm = p->fontMetrics();
-    int yPos;                       // vertical text position
-    if ( mPixmap.height() < fm.height() )
-        yPos = fm.ascent() + fm.leading()/2;
-    else
-        yPos = mPixmap.height()/2 - fm.height()/2 + fm.ascent();
-    p->drawText( mPixmap.width() + 5, yPos, text() );
-}
-
-int AmorListBoxItem::height(const QListBox *lb ) const
-{
-    return QMAX( mPixmap.height(), lb->fontMetrics().lineSpacing() + 1 );
-}
-
-int AmorListBoxItem::width(const QListBox *lb ) const
-{
-    return mPixmap.width() + lb->fontMetrics().width( text() ) + 6;
-}
-
