@@ -16,7 +16,7 @@
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
  *
- *  $Id: sidebarwidget.h 465369 2005-09-29 14:33:08Z mueller $
+ *  $Id: sidebarwidget.h 631359 2007-02-07 20:22:23Z aseigo $
  */
 
 #ifndef __SIDEBARWIDGET_H__
@@ -24,17 +24,17 @@
 
 
 #include <sidebarwidgetbase.h>
-#include <qvbox.h>
+#include <kvbox.h>
 
 class sidebarwidget : public sidebarwidgetbase
 {
 Q_OBJECT
 public:
-    sidebarwidget(QWidget* parent, const char* name = 0);
+    explicit sidebarwidget(QWidget* parent, const char* name = 0);
     virtual ~sidebarwidget();
     void addWidget(QWidget *w, const QString &s);
     QWidget *viewport();
-    QVBox *view;
+    KVBox *view;
 
 };
 
