@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001-2004 Ian Geiser <geiseri@kde.org>
-   Copyright (C) 2002-2004 Nadeem Hasan <nhasan@kde.org>
-   Copyright (C) 2003-2004 John Ratke
+   Copyright 2001-2004 Ian Geiser <geiseri@kde.org>
+   Copyright 2002-2004 Nadeem Hasan <nhasan@kde.org>
+   Copyright 2003-2004 John Ratke <jratke@comcast.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,17 +23,14 @@
 #define _WEATHER_SERVICE
 
 #include <qstringlist.h>
-#include <dcopobject.h>
 #include <qpixmap.h>
 
 class WeatherLib;
 class StationDatabase;
 
-class WeatherService : public QObject, public DCOPObject
+class WeatherService : public QObject
 {
 	Q_OBJECT
-	K_DCOP
-
 	private:
 		WeatherLib  *m_weatherLib;
 
@@ -46,12 +43,12 @@ class WeatherService : public QObject, public DCOPObject
 		WeatherService(QObject *parent, const char *name);
 		~WeatherService();
 
-	k_dcop_signals:
+	signals:
 		void fileUpdating(QString);
 		void fileUpdate(QString);
 		void stationRemoved(QString);
 
-	k_dcop:
+	public slots:
 		QString temperature(const QString &stationID);
 		QString dewPoint(const QString &stationID);
 		QString relativeHumidity(const QString &stationID);
@@ -59,8 +56,8 @@ class WeatherService : public QObject, public DCOPObject
 		QString windChill(const QString &stationID);
 		QString wind(const QString &stationID);
 		QString pressure(const QString &stationID);
-		QPixmap currentIcon(const QString &stationID);
-		QPixmap icon(const QString &stationID);
+		QByteArray currentIcon(const QString &stationID);
+		QByteArray icon(const QString &stationID);
 		QString currentIconString(const QString &stationID);
 		QString iconFileName(const QString &stationID);
 		QString date(const QString &stationID);
